package com.chilunyc.fumao.api.company;

import com.chilunyc.fumao.common.response.JsonResponse;
import com.chilunyc.fumao.common.shiro.AuthRoles;
import com.chilunyc.fumao.company.model.Company;
import com.chilunyc.fumao.company.model.CompanyAdmin;
import com.chilunyc.fumao.company.model.Place;
import com.chilunyc.fumao.company.request.place.PlacePageRequest;
import com.chilunyc.fumao.company.service.PlaceService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 *
 */
@Log4j
@Api(description = "商场")
@RestController
@RequestMapping("/company/place")
@PreAuthorize(AuthRoles.CompanyAdminExp)
class PlaceController {

    @Autowired
    PlaceService placeService;


    @ApiOperation(value = "分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "PageRequest")
    })
    @RequestMapping(value = "/find", method = RequestMethod.POST)
    JsonResponse<Page<Place>> page(CompanyAdmin companyAdmin, @RequestBody PlacePageRequest request) {
        request.setCompanyId(companyAdmin.getCompanyId());
        Page<Place> page = placeService.page(request);
        return JsonResponse.success(page);
    }

    @ApiOperation(value = "详情")
    @ApiImplicitParams({
    })
    @RequestMapping(value = "/find/{id}", method = RequestMethod.GET)
    JsonResponse<Place> info(@PathVariable Long id) {
        Place placeResponse = placeService.find(id);
        return JsonResponse.success(placeResponse);
    }


//    @ApiOperation(value = "新增 | 编辑")
//    @ApiImplicitParams({
//            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "Place")
//    })
//    @RequestMapping(value = "/edit", method = RequestMethod.POST)
//    JsonResponse edit(@RequestBody @Valid PlaceEditRequest request) {
//        marketService.edit(request);
//        return JsonResponse.success();
//    }
//
//    @ApiOperation(value = "删除")
//    @ApiImplicitParams({
//            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "IdRequest")
//    })
//    @RequestMapping(value = "/delete", method = RequestMethod.POST)
//    JsonResponse remove(@RequestBody @Valid IdsRequest request) {
//        marketService.remove(request);
//        return JsonResponse.success();
//    }

    @ApiOperation(value = "所有")
    @ApiImplicitParams({
    })
    @RequestMapping(value = "/find/all", method = RequestMethod.GET)
    JsonResponse<List<Place>> all(CompanyAdmin companyAdmin, PlacePageRequest request) {
        request.setCompanyId(companyAdmin.getCompanyId());
        List<Place> result = placeService.all(request);
        return JsonResponse.success(result);
    }

}