package com.chilunyc.fumao.api.place;

import com.chilunyc.fumao.common.request.IdsRequest;
import com.chilunyc.fumao.common.response.JsonResponse;
import com.chilunyc.fumao.common.shiro.AuthRoles;
import com.chilunyc.fumao.place.model.Trade;
import com.chilunyc.fumao.place.request.trade.TradeEditRequest;
import com.chilunyc.fumao.place.request.trade.TradePageRequest;
import com.chilunyc.fumao.place.service.TradeService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

/**
 *
 */
@Log4j
@Api(description = "订单")
@RestController
@RequestMapping("/place/trade")
@PreAuthorize(AuthRoles.PlaceAdminExp + " OR " + AuthRoles.PlaceCustomerExp)
class TradeController {

    @Autowired
    TradeService tradeService;


    @ApiOperation(value = "分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "PageRequest")
    })
    @RequestMapping(value = "/find", method = RequestMethod.POST)
    JsonResponse<Page<Trade>> page(@RequestBody TradePageRequest request) {
        Page<Trade> page = tradeService.page(request);
        return JsonResponse.success(page);
    }

    @ApiOperation(value = "详情")
    @ApiImplicitParams({
    })
    @RequestMapping(value = "/find/{id}", method = RequestMethod.GET)
    JsonResponse<Trade> info(@PathVariable Long id) {
        Trade tradeResponse = tradeService.find(id);
        return JsonResponse.success(tradeResponse);
    }


    @ApiOperation(value = "新增 | 编辑")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "Trade")
    })
    @RequestMapping(value = "/edit", method = RequestMethod.POST)
    JsonResponse edit(@RequestBody @Valid TradeEditRequest request) {
        tradeService.edit(request);
        return JsonResponse.success();
    }

    @ApiOperation(value = "删除")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "request", required = true, paramType = "body", dataType = "IdRequest")
    })
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    JsonResponse remove(@RequestBody @Valid IdsRequest request) {
        tradeService.remove(request);
        return JsonResponse.success();
    }


}