package com.chilunyc.fumao.config.web;

import com.chilunyc.fumao.common.config.ApplicationProperty;
import com.chilunyc.fumao.config.web.arguments.DateArgumentResolver;
import com.chilunyc.fumao.config.web.arguments.LoginUserArgumentResolver;
import com.chilunyc.fumao.config.web.filter.DBRouteFilter;
import com.chilunyc.fumao.config.web.interceptor.CorsInterceptor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.web.servlet.FilterRegistrationBean;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.web.method.support.HandlerMethodArgumentResolver;
import org.springframework.web.servlet.config.annotation.CorsRegistry;
import org.springframework.web.servlet.config.annotation.InterceptorRegistry;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurerAdapter;

import java.util.List;

/**
 *
 */
@Configuration
public class WebConfig extends WebMvcConfigurerAdapter {

    @Autowired
    private CorsInterceptor corsInterceptor;

    @Autowired
    private LoginUserArgumentResolver jwtValueArgumentResolver;

    @Autowired
    private ApplicationProperty applicationConfig;

    @Autowired
    private DBRouteFilter dbRouteFilter;

    /**
     * 跨域访问
     *
     * @param registry
     */
    @Override
    public void addCorsMappings(CorsRegistry registry) {
        registry
                .addMapping("/**/*")
                .allowedOrigins("*")
                .allowedMethods("*")
                .allowedHeaders("*")
                .allowCredentials(true)
        ;
    }


    @Override
    public void addInterceptors(InterceptorRegistry registry) {
        registry.addInterceptor(corsInterceptor);
    }

    @Override
    public void addArgumentResolvers(List<HandlerMethodArgumentResolver> argumentResolvers) {
        argumentResolvers.add(jwtValueArgumentResolver);
        argumentResolvers.add(new DateArgumentResolver());
    }

    @Bean
    FilterRegistrationBean dbRouteFilter() {
        FilterRegistrationBean filterRegistrationBean = new FilterRegistrationBean();
        filterRegistrationBean.setFilter(dbRouteFilter);
        filterRegistrationBean.addUrlPatterns("/*");
        filterRegistrationBean.setOrder(Integer.MAX_VALUE); //最后初始化, 依赖Jwt数值
        return filterRegistrationBean;
    }
}
