package com.chilunyc.fumao.config.web.arguments;

import org.apache.commons.lang3.ClassUtils;
import org.apache.commons.lang3.StringUtils;
import org.apache.commons.lang3.time.DateUtils;
import org.springframework.core.MethodParameter;
import org.springframework.web.bind.support.WebDataBinderFactory;
import org.springframework.web.context.request.NativeWebRequest;
import org.springframework.web.method.support.HandlerMethodArgumentResolver;
import org.springframework.web.method.support.ModelAndViewContainer;

import java.util.Date;

/**
 *
 */
public class DateArgumentResolver implements HandlerMethodArgumentResolver {

    @Override
    public boolean supportsParameter(MethodParameter methodParameter) {
        return ClassUtils.isAssignable(methodParameter.getParameterType(), Date.class);
    }

    @Override
    public Object resolveArgument(MethodParameter methodParameter, ModelAndViewContainer modelAndViewContainer, NativeWebRequest nativeWebRequest, WebDataBinderFactory webDataBinderFactory) throws Exception {
        String parameterName = methodParameter.getParameterName();
        String value = nativeWebRequest.getParameter(parameterName);
        if (StringUtils.isBlank(value) || StringUtils.equalsIgnoreCase("undefined", value)) {
            return null;
        } else if (value.length() <= 10) {
            return DateUtils.parseDate(value, "yyyy-MM-dd");
        } else if (value.length() > 16) {
            return DateUtils.parseDate(value, "yyyy-MM-dd  HH:mm:ss");
        } else {
            return null;
        }
    }
}
