package com.chilunyc.fumao.config.web.interceptor;

import com.chilunyc.fumao.common.context.RequestHolder;
import org.springframework.beans.BeansException;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;
import org.springframework.stereotype.Component;
import org.springframework.web.cors.CorsConfiguration;
import org.springframework.web.servlet.handler.AbstractHandlerMapping;
import org.springframework.web.servlet.handler.HandlerInterceptorAdapter;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.ArrayList;
import java.util.Map;

/**
 *
 */
@Component
public class CorsInterceptor extends HandlerInterceptorAdapter implements ApplicationContextAware {

    private AbstractHandlerMapping handlerMapping;
    private CorsConfiguration cors;
    private ApplicationContext applicationContext;

    @Override
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler) throws Exception {
        if (handlerMapping == null) {
            synchronized (applicationContext) {
                if (handlerMapping == null) {
                    handlerMapping = applicationContext.getBean(AbstractHandlerMapping.class);
                    Map<String, CorsConfiguration> corsConfigurations = handlerMapping.getCorsConfigurations();
                    this.cors = new ArrayList<>(corsConfigurations.values()).get(0);
                }
            }
        }

        //
        handlerMapping.getCorsProcessor().processRequest(cors, request, response);
        return super.preHandle(request, response, handler);
    }

    @Override
    public void setApplicationContext(ApplicationContext applicationContext) throws BeansException {
        this.applicationContext = applicationContext;
    }

    @Override
    public void afterCompletion(HttpServletRequest request, HttpServletResponse response, Object handler, Exception ex) throws Exception {
        super.afterCompletion(request, response, handler, ex);
        RequestHolder.clean();
    }
}
