package com.chilunyc.fumao.common.aop.limit;

import com.chilunyc.fumao.common.aop.BaseAop;
import com.chilunyc.fumao.common.exception.SystemException;
import com.chilunyc.fumao.common.util.SpelHelper;
import org.apache.commons.lang3.StringUtils;
import org.aspectj.lang.JoinPoint;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Before;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Component;

import java.util.Map;

/**
 *
 */
@Component
@Aspect
public class LimitAop extends BaseAop {

    @Autowired
    private StringRedisTemplate redisTemplate;

    @Before("@annotation(com.chilunyc.fumao.common.aop.limit.Limit)")
    void execute(JoinPoint joinPoint) throws Throwable {
        Limit annotation = getAnnotation(joinPoint, Limit.class);
        Map<String, Object> args = getArgs(joinPoint);
        String redisKey = getMethodName(joinPoint) + (StringUtils.isBlank(annotation.key()) ? "" : SpelHelper.exec(annotation.key(), args));

        // 没值, 缓存一下
        if (redisTemplate.opsForValue().setIfAbsent(redisKey, "v")) {
            redisTemplate.expire(redisKey, annotation.timeout(), annotation.unit());
        }
        // 有值, 所有有人提交过了, 出错
        else {
            throw new SystemException("000007", new Object[]{annotation.message()});
        }
    }
}
