package com.chilunyc.fumao.common.aop.lock;

import com.chilunyc.fumao.common.aop.BaseAop;
import com.chilunyc.fumao.common.util.SpelHelper;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.redisson.api.RLock;
import org.redisson.api.RedissonClient;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Map;

/**
 *
 */
@Component
@Aspect
public class LockAop extends BaseAop {

    @Autowired
    private RedissonClient redissonClient;

    @Around("@annotation(com.chilunyc.fumao.common.aop.lock.Lock)")
    Object execute(ProceedingJoinPoint joinPoint) throws Throwable {
        Lock annotation = getAnnotation(joinPoint, Lock.class);
        Map<String, Object> args = getArgs(joinPoint);
        String redisKey = getMethodName(joinPoint) + "_" + SpelHelper.exec(annotation.key(), args);
        RLock lock = redissonClient.getLock(redisKey);
        try {
            lock.lock();
            return joinPoint.proceed();
        } finally {
            lock.unlock();
        }
    }
}
