package com.chilunyc.fumao.common.config;

import com.alibaba.fastjson.JSON;
import lombok.extern.log4j.Log4j;
import org.apache.commons.io.IOUtils;
import org.springframework.beans.factory.InitializingBean;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.io.DefaultResourceLoader;
import org.springframework.data.redis.core.BoundHashOperations;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import java.io.InputStream;

/**
 *
 */
@Log4j
@Service
public class ConfigService implements InitializingBean {

    @Autowired
    private RedisTemplate<String, String> redisTemplate;

    @Autowired
    private ApplicationProperty applicationProperty;
    private BoundHashOperations<String, Object, Object> ops;

    public void set(ConfigEnum key, Object v) {
        this.ops.put(key.name(), v);
    }

    public <T> T get(ConfigEnum key) {
        return (T) this.ops.get(key.name());
    }

    @Override
    public void afterPropertiesSet() throws Exception {
        this.ops = redisTemplate.boundHashOps(ConfigService.class.getName());
        if (this.ops.size() == 0) {
            InputStream inputStream = new DefaultResourceLoader().getResource(applicationProperty.getConfigPath()).getInputStream();
            String configContent = IOUtils.toString(inputStream, "utf-8");
            this.ops.putAll(JSON.parseObject(configContent));
        }
    }
}
