package com.chilunyc.fumao.common.db.datasource;

import com.zaxxer.hikari.HikariDataSource;
import lombok.extern.log4j.Log4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.DisposableBean;
import org.springframework.jdbc.datasource.AbstractDataSource;

import javax.sql.DataSource;
import java.sql.Connection;
import java.sql.SQLException;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

/**
 *  on 2018/7/26.
 */
@Log4j
public class DynamicDataSource extends AbstractDataSource implements DisposableBean {

    private Map<String, DataSource> dataSourceMap = new ConcurrentHashMap<>();

    private String defaultDbName;

    /**
     * @param dbName
     * @param dataSource
     */
    public void addDataSource(String dbName, DataSource dataSource, boolean isDefault) {
        dataSourceMap.put(dbName, dataSource);
        if (isDefault) {
            this.defaultDbName = dbName;
        }
    }

    public Connection getConnection() throws SQLException {
        String s = DynamicDataSourceHolder.get();
        if (StringUtils.isBlank(s)) {
            s = defaultDbName;
        }
        if (log.isInfoEnabled()) {
            log.info("使用 =>[ " + s + " ]库");
        }
        return dataSourceMap.get(s).getConnection();
    }

    public Connection getConnection(String username, String password) throws SQLException {
        return getConnection();
    }

    @Override
    public void destroy() throws Exception {
        dataSourceMap.values().forEach(dataSource -> {
            ((HikariDataSource) dataSource).close();
        });
    }
}
