package com.chilunyc.fumao.common.upload.service;

import com.chilunyc.fumao.common.exception.SystemException;
import com.chilunyc.fumao.common.upload.config.UploadProperties;
import com.chilunyc.fumao.common.upload.response.UploadResponse;
import com.aliyun.oss.OSSClient;
import com.aliyun.oss.common.utils.BinaryUtil;
import com.aliyun.oss.model.PolicyConditions;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;
import java.util.UUID;

/**
 *
 */
@Service
@Transactional
public class UploadService {

    private Logger logger = LoggerFactory.getLogger(UploadService.class);

    @Autowired
    private UploadProperties uploadProperties;

    @Autowired
    private OSSClient client;

    public UploadResponse getAuth() {
        try {
            long expireTime = 30;
            long expireEndTime = System.currentTimeMillis() + expireTime * 1000;
            Date expiration = new Date(expireEndTime);
            PolicyConditions policyConds = new PolicyConditions();
            policyConds.addConditionItem(PolicyConditions.COND_CONTENT_LENGTH_RANGE, 0, 1048576000);
            String postPolicy = client.generatePostPolicy(expiration, policyConds);
            byte[] binaryData = postPolicy.getBytes("utf-8");
            String encodedPolicy = BinaryUtil.toBase64String(binaryData);
            String postSignature = client.calculatePostSignature(postPolicy);

            return UploadResponse
                    .builder()
                    .key(UUID.randomUUID().toString().replaceAll("-", ""))
                    .OSSAccessKeyId(uploadProperties.getAccessId())
                    .policy(encodedPolicy)
                    .signature(postSignature)
                    .host(uploadProperties.getHost())
                    .expire(String.valueOf(expireEndTime / 1000))
                    .build();
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            throw new SystemException("创建上传凭证失败");
        }
    }
}
