package com.chilunyc.fumao.common.util;

import com.chilunyc.fumao.common.exception.SystemException;
import org.joda.time.DateTime;

import java.util.Calendar;
import java.util.Date;

/**
 *
 */
public class DateRangeHelper {

    public static void main(String[] args) {
        Date[] dates = DateRangeHelper.yearRange();
        System.out.println(dates[0] + " => " + dates[1]);
    }

    /**
     * 昨天 0 点 - 23:59:59
     *
     * @return
     */
    public static Date[] yesterdayRange() {
        DateTime start = DateTime.now().withTimeAtStartOfDay();
        DateTime end = start.plusDays(1).minusSeconds(1);
        return new Date[]{
                start.toDate(),
                end.toDate()
        };
    }

    /**
     * 昨天 0 点 - 23:59:59
     *
     * @return
     */
    public static Date[] todayRange() {
        DateTime start = DateTime.now().withTimeAtStartOfDay();
        return new Date[]{
                start.toDate(),
                new Date()
        };
    }

    /**
     * 近7天
     *
     * @return
     */
    public static Date[] weekRange() {
        DateTime end = DateTime.now();
        DateTime start = end.minusDays(7).withTimeAtStartOfDay();
        return new Date[]{
                start.toDate(),
                end.toDate()
        };
    }

    /**
     * 近30天
     *
     * @return
     */
    public static Date[] monthRange() {
        DateTime end = DateTime.now();
        DateTime start = end.minusDays(31).withTimeAtStartOfDay();
        return new Date[]{
                start.toDate(),
                end.toDate()
        };
    }

    /**
     * 近1年
     *
     * @return
     */
    public static Date[] yearRange(Date startDate, Date endDate) {
        if (startDate == null) {
            Calendar calendar = Calendar.getInstance();
            calendar.set(Calendar.MONTH, 0);
            startDate = calendar.getTime();
        }
        if (endDate != null && endDate.before(startDate)) {
            throw new SystemException("300016");
        }
        if (endDate == null) {
            Calendar calendar = Calendar.getInstance();
            calendar.setTime(startDate);
            calendar.add(Calendar.YEAR, 1);
            endDate = calendar.getTime();
        }
        return new Date[]{startDate, endDate};
    }


    public static Date[] yearRange() {
        DateTime end = DateTime.now();
        DateTime start = end.minusYears(1).withTimeAtStartOfDay();
        return new Date[]{
                start.toDate(),
                end.toDate()
        };

    }

    public static Date[] yearRange(Integer year) {
        DateTime end = DateTime.now();
        DateTime start = end.minusYears(year == null ? 1 : year).withTimeAtStartOfDay();
        return new Date[]{
                start.toDate(),
                end.toDate()
        };
    }
}
