package com.chilunyc.fumao.company.service;

import com.chilunyc.fumao.common.context.RequestHolder;
import com.chilunyc.fumao.common.exception.SystemException;
import com.chilunyc.fumao.common.log.model.EventTarget;
import com.chilunyc.fumao.common.log.model.EventType;
import com.chilunyc.fumao.common.log.service.EventService;
import com.chilunyc.fumao.common.request.IdsRequest;
import com.chilunyc.fumao.common.request.LoginRequest;
import com.chilunyc.fumao.common.util.BeanHelper;
import com.chilunyc.fumao.common.util.jpa.query.QueryBuilder;
import com.chilunyc.fumao.common.util.security.SaltHelper;
import com.chilunyc.fumao.company.model.Company;
import com.chilunyc.fumao.company.model.CompanyAdmin;
import com.chilunyc.fumao.company.repository.CompanyAdminRepository;
import com.chilunyc.fumao.company.request.companyAdmin.CompanyAdminEditRequest;
import com.chilunyc.fumao.company.request.companyAdmin.CompanyAdminPageRequest;
import com.chilunyc.fumao.company.request.placeAdmin.PlaceAdminEditRequest;
import lombok.extern.log4j.Log4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 *
 */
@Log4j
@Service
@Transactional
public class CompanyAdminService {


    @Autowired
    private CompanyAdminRepository companyAdminRepository;

    @Autowired
    private EventService eventService;

    public Page<CompanyAdmin> page(CompanyAdminPageRequest request) {
        return companyAdminRepository.findAll(QueryBuilder.build(request), request.getPage());
    }


    public CompanyAdmin find(Long id) {
        CompanyAdmin one = companyAdminRepository.findOne(id);
        return one;
    }


    public CompanyAdmin edit(CompanyAdminEditRequest request) {
        if (request.getId() == null &&
                companyAdminRepository.existsByMobile(request.getMobile())) {
            throw new SystemException("100000");
        }

        CompanyAdmin companyAdmin = new CompanyAdmin();
        BeanHelper.copyProperties(companyAdmin, request);
        String salt = SaltHelper.salt();
        companyAdmin.setOriginPassword(request.getPassword());
        companyAdmin.setSalt(salt);
        companyAdmin.setPassword(SaltHelper.exec(request.getPassword(), salt));
        companyAdmin = companyAdminRepository.save(companyAdmin);
        eventService.add(RequestHolder.get(), EventTarget.System, EventType.编辑集团管理员, companyAdmin.getId(), request);
        return companyAdmin;
    }

    public void remove(IdsRequest<Long> request) {
        request
                .getIds()
                .forEach((id) -> {
                    companyAdminRepository.delete(id);
                });
        eventService.add(RequestHolder.get(), EventTarget.System, EventType.删除集团管理员, null, request.getIds());
    }


    public List<CompanyAdmin> all(CompanyAdminPageRequest request) {
        if (request == null) {
            request = new CompanyAdminPageRequest();
        }
        List<CompanyAdmin> all = companyAdminRepository.findAll(QueryBuilder.build(request));
        return all;
    }


    public CompanyAdmin login(LoginRequest request) {
        CompanyAdmin companyAdmin = companyAdminRepository.findByMobile(request.getMobile());
        if (companyAdmin != null &&
                SaltHelper.isEquals(companyAdmin.getPassword(), request.getPassword(), companyAdmin.getSalt())) {
            return companyAdmin;
        }
        throw new SystemException("000004");
    }

    public CompanyAdmin findByCompanyId(Long id, Long companyId) {
        return companyAdminRepository.findByIdAndCompanyId(id, companyId);
    }

    public void removeByCompanyId(IdsRequest<Long> request, Long companyId) {
        companyAdminRepository.deleteByIdAndCompanyId(request.getIds(), companyId);
    }

    public void resetPassword(Long id, Long companyId) {
        CompanyAdmin companyAdmin = companyAdminRepository.findByIdAndCompanyId(id, companyId);
        if (companyAdmin != null) {
            companyAdmin.setPassword(SaltHelper.exec(companyAdmin.getOriginPassword(), companyAdmin.getSalt()));
            companyAdminRepository.save(companyAdmin);
        }
    }
}
