package com.chilunyc.fumao.company.service;

import com.chilunyc.fumao.common.context.RequestHolder;
import com.chilunyc.fumao.common.db.datasource.DynamicDataSource;
import com.chilunyc.fumao.common.log.model.EventTarget;
import com.chilunyc.fumao.common.log.model.EventType;
import com.chilunyc.fumao.common.log.service.EventService;
import com.chilunyc.fumao.common.request.IdsRequest;
import com.chilunyc.fumao.common.util.BeanHelper;
import com.chilunyc.fumao.common.util.jpa.query.QueryBuilder;
import com.chilunyc.fumao.company.config.CompanyConfiguration;
import com.chilunyc.fumao.company.model.Company;
import com.chilunyc.fumao.company.repository.CompanyRepository;
import com.chilunyc.fumao.company.request.company.CompanyEditRequest;
import com.chilunyc.fumao.company.request.company.CompanyPageRequest;
import lombok.extern.log4j.Log4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 *
 */
@Log4j
@Service
@Transactional
public class CompanyService {


    @Autowired
    private CompanyRepository companyRepository;

    @Autowired
    private EventService eventService;

    @Autowired
    private CompanyConfiguration companyConfiguration;

    public Page<Company> page(CompanyPageRequest request) {
        return companyRepository.findAll(QueryBuilder.build(request), request.getPage());
    }


    public Company find(Long id) {
        Company one = companyRepository.findOne(id);
        return one;
    }


    public Company edit(CompanyEditRequest request) {
        Company company = new Company();
        BeanHelper.copyProperties(company, request);
        String[] region = request.getRegion();
        company.setProvince(region[0]);
        company.setCity(region[1]);
        company.setArea(region[2]);
        company = companyRepository.save(company);


        // 调用flyway, 创建一个数据库实例
        if (request.getId() == null) {
            companyConfiguration.init(company);
        }

        eventService.add(RequestHolder.get(), EventTarget.System, EventType.编辑集团, company.getId(), request);
        return company;
    }

    public void remove(IdsRequest<Long> request) {
        request
                .getIds()
                .forEach((id) -> {
                    companyRepository.delete(id);
                });
        eventService.add(RequestHolder.get(), EventTarget.System, EventType.删除集团, null, request.getIds());
    }


    public List<Company> all(CompanyPageRequest request) {
        if (request == null) {
            request = new CompanyPageRequest();
        }
        List<Company> all = companyRepository.findAll(QueryBuilder.build(request));
        return all;
    }


}
