package com.chilunyc.fumao.place.model;

import com.chilunyc.fumao.place.model.enums.Sex;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.hibernate.annotations.GenericGenerator;
import org.hibernate.annotations.Parameter;
import org.springframework.data.annotation.CreatedDate;
import org.springframework.data.jpa.domain.support.AuditingEntityListener;

import javax.persistence.*;
import java.io.Serializable;
import java.util.Date;

/**
 *
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
@Entity
@Table(name = "fumao_customer", indexes = {
        @Index(name = "customer_mobile", columnList = "mobile"),
})
@EntityListeners(AuditingEntityListener.class)
public class Customer implements Serializable {

    /**
     * 编号
     */
    @Id
    @Column(length = 64)
    @GeneratedValue(generator = "custom")
    @GenericGenerator(name = "custom", strategy = "com.chilunyc.fumao.common.util.jpa.CustomIdentifierGenerator", parameters = {@Parameter(name = "type", value = "Number")})
    private Long id;

    /**
     * 名称
     */
    @Column(columnDefinition = "varchar(64) comment '名称'")
    private String name;

    /**
     * 手机号
     */
    @Column(columnDefinition = "varchar(20) comment '手机号'")
    private String mobile;

    /**
     * 出生日期
     */
    @Column(columnDefinition = "date comment '出生日期'")
    private Date birth;

    /**
     * 学历
     */
    @Column(columnDefinition = "text comment '学历'")
    private String education;

    /**
     * 性别
     */
    @Column(columnDefinition = "int(1) comment '性别'")
    @Enumerated(EnumType.ORDINAL)
    private Sex sex;

    /**
     * 邮箱
     */
    @Column(columnDefinition = "varchar(64) comment '邮箱'")
    private String email;

    /**
     * 积分
     */
    @Column(columnDefinition = "int(9) comment '积分'")
    private Integer score;

    /**
     * 住址
     */
    @Column(columnDefinition = "varchar(64) comment '住址'")
    private String address;

    /**
     * 注册渠道
     */
    @Column(columnDefinition = "varchar(64) comment '注册渠道'")
    private String channel;

    /**
     * 创建时间
     */
    @CreatedDate
    @Column(columnDefinition = "datetime comment '创建时间'")
    private Date createTime;

}
