package com.chilunyc.fumao.place.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.hibernate.annotations.GenericGenerator;
import org.hibernate.annotations.Parameter;
import org.springframework.data.annotation.CreatedDate;
import org.springframework.data.jpa.domain.support.AuditingEntityListener;

import javax.persistence.*;
import java.io.Serializable;
import java.util.Date;
import java.util.List;


/**
 *
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
@Entity
@Table(name = "fumao_merchant", indexes = {
        @Index(name = "merchant_mobile", columnList = "mobile")
})
@EntityListeners(AuditingEntityListener.class)
public class Merchant implements Serializable {

    /**
     * 编号
     */
    @Id
    @Column(length = 64)
    @GeneratedValue(generator = "custom")
    @GenericGenerator(name = "custom", strategy = "com.chilunyc.fumao.common.util.jpa.CustomIdentifierGenerator", parameters = {@Parameter(name = "type", value = "Number")})
    private Long id;

    /**
     * 图片
     */
    @Column(columnDefinition = "varchar(128) comment '图片'")
    private String image;

    /**
     * 名称
     */
    @Column(columnDefinition = "varchar(64) comment '名称'")
    private String name;

    /**
     * 联系方式
     */
    @Column(columnDefinition = "varchar(20) comment '联系方式'")
    private String mobile;

    /**
     * 创建时间
     */
    @CreatedDate
    @Column(columnDefinition = "datetime comment '创建时间'")
    private Date createTime;

    @JsonIgnore
    @JoinColumn(name = "merchantId")
    @OneToMany(fetch = FetchType.LAZY)
    private List<Shop> shopList;

}
