package com.chilunyc.fumao.place.model;

import com.chilunyc.fumao.common.context.LoginUser;
import com.chilunyc.fumao.common.shiro.AuthRoles;
import com.fasterxml.jackson.annotation.JsonIgnore;
import io.jsonwebtoken.Claims;
import io.jsonwebtoken.JwtBuilder;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.hibernate.annotations.GenericGenerator;
import org.hibernate.annotations.Parameter;
import org.springframework.data.annotation.CreatedDate;
import org.springframework.data.jpa.domain.support.AuditingEntityListener;

import javax.persistence.*;
import java.io.Serializable;
import java.util.Date;

/**
 *
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
@Entity
@Table(name = "fumao_merchant_admin", indexes = {
        @Index(name = "merchant_admin_mobile", columnList = "mobile"),
        @Index(name = "merchant_admin_merchantId", columnList = "merchantId")
})
@EntityListeners(AuditingEntityListener.class)
public class MerchantAdmin implements Serializable, LoginUser<Long> {

    /**
     * 编号
     */
    @Id
    @Column(length = 64)
    @GeneratedValue(generator = "custom")
    @GenericGenerator(name = "custom", strategy = "com.chilunyc.fumao.common.util.jpa.CustomIdentifierGenerator", parameters = {@Parameter(name = "type", value = "Number")})
    private Long id;

    /**
     * 名称
     */
    @Column(columnDefinition = "text comment '名称'")
    private String name;

    /**
     * 密码
     */
    @Column(columnDefinition = "varchar(32) comment '原始密码'")
    private String originPassword;

    /**
     * 密码
     */
    @JsonIgnore
    @Column(columnDefinition = "varchar(32) comment '密码'")
    private String password;

    /**
     * 盐值
     */
    @JsonIgnore
    @Column(columnDefinition = "varchar(32) comment '盐值'")
    private String salt;

    /**
     * 手机号
     */
    @Column(columnDefinition = "varchar(20) comment '手机号'")
    private String mobile;

    /**
     * 商户
     */
    @Column(columnDefinition = "bigint(64) comment '商户'")
    private Long merchantId;


    /**
     * 创建时间
     */
    @CreatedDate
    @Column(columnDefinition = "datetime comment '创建时间'")
    private Date createTime;

    @Override
    public String[] toRoles() {
        return new String[]{AuthRoles.MerchantAdmin};
    }

    @Override
    public void fromJwt(Claims claims) {
        this.id = Long.parseLong(claims.getSubject());
        this.merchantId = claims.get("mid", Long.class);
        this.name = claims.get("n", String.class);
    }

    @Override
    public void toJwt(JwtBuilder claims) {
        claims.setSubject(this.id.toString());
        claims.claim("mid", this.merchantId);
        claims.claim("n", this.name);
    }
}
