package com.chilunyc.fumao.place.model;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.hibernate.annotations.*;
import org.hibernate.annotations.Parameter;
import org.springframework.data.annotation.CreatedDate;
import org.springframework.data.jpa.domain.support.AuditingEntityListener;

import javax.persistence.*;
import javax.persistence.Entity;
import javax.persistence.ForeignKey;
import javax.persistence.Index;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 *
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
@Entity
@Table(name = "fumao_shop", indexes = {
        @Index(name = "shop_number", columnList = "number"),
        @Index(name = "shop_merchantId", columnList = "merchantId"),
        @Index(name = "shop_placeId", columnList = "placeId")
})
@EntityListeners(AuditingEntityListener.class)
public class Shop implements Serializable {

    /**
     * 编号
     */
    @Id
    @Column(length = 64)
    @GeneratedValue(generator = "custom")
    @GenericGenerator(name = "custom", strategy = "com.chilunyc.fumao.common.util.jpa.CustomIdentifierGenerator", parameters = {@Parameter(name = "type", value = "Number")})
    private Long id;

    /**
     * 城市
     */
    @Column(columnDefinition = "varchar(10) comment '省份'")
    private String province;

    /**
     * 城市
     */
    @Column(columnDefinition = "varchar(10) comment '地区'")
    private String area;

    /**
     * 城市
     */
    @Column(columnDefinition = "varchar(10) comment '城市'")
    private String city;

    /**
     * POI
     */
    @Column(columnDefinition = "varchar(64) comment 'POI'")
    private String poi;

    /**
     * 经度
     */
    @Column(columnDefinition = "varchar(12) comment '经度'")
    private String lat;

    /**
     * 纬度
     */
    @Column(columnDefinition = "varchar(12) comment '纬度'")
    private String lng;

    /**
     * 地址
     */
    @Column(columnDefinition = "varchar(64) comment '地址'")
    private String address;

    /**
     * 建筑面积
     */
    @Column(columnDefinition = "double(9,2) comment '建筑面积'")
    private Double totalArea;

    /**
     * 营业面积
     */
    @Column(columnDefinition = "double(9,2) comment '营业面积'")
    private Double sellingArea;

    /**
     * 商铺号
     */
    @Column(columnDefinition = "varchar(32) comment '商铺号'")
    private String number;

    /**
     * 楼层
     */
    @Column(columnDefinition = "bigint(64) comment '楼层'")
    private Long floor;

    /**
     * 封面
     */
    @Column(columnDefinition = "varchar(255) comment '封面'")
    private String cover;

    /**
     * 商户
     */
    @Column(columnDefinition = "bigint(64) comment '商户'")
    private Long merchantId;

    /**
     * 商场
     */
    @Column(columnDefinition = "bigint(64) comment '商场'")
    private Long placeId;

    /**
     * 创建时间
     */
    @CreatedDate
    @Column(columnDefinition = "datetime comment '创建时间'")
    private Date createTime;

    /**
     *
     */
    @ManyToOne()
    @Fetch(FetchMode.JOIN)
    @JoinColumn(name = "merchantId", insertable = false, updatable = false, foreignKey = @ForeignKey(name = "none", value = ConstraintMode.NO_CONSTRAINT))
    @NotFound(action = NotFoundAction.IGNORE)
    private Merchant merchant;
}
