package com.chilunyc.fumao.place.model;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.hibernate.annotations.GenericGenerator;
import org.hibernate.annotations.Parameter;
import org.springframework.data.annotation.CreatedDate;
import org.springframework.data.jpa.domain.support.AuditingEntityListener;

import javax.persistence.*;
import java.io.Serializable;
import java.util.Date;

/**
 *
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
@Entity
@Table(name = "fumao_tag", indexes = {
        @Index(name = "tag_name", columnList = "name"),
        @Index(name = "tag_cate", columnList = "cate"),
        @Index(name = "tag_targetId", columnList = "targetId")
})
@EntityListeners(AuditingEntityListener.class)
public class Tag implements Serializable {

    /**
     * 编号
     */
    @Id
    @Column(length = 64)
    @GeneratedValue(generator = "custom")
    @GenericGenerator(name = "custom", strategy = "com.chilunyc.fumao.common.util.jpa.CustomIdentifierGenerator", parameters = {@Parameter(name = "type", value = "Number")})
    private Long id;

    /**
     * 名称
     */
    @Column(columnDefinition = "varchar(32) comment '名称'")
    private String name;

    /**
     * 数值
     */
    @Column(columnDefinition = "varchar(64) comment '数值'")
    private String value;

    /**
     * 组
     */
    @Column(columnDefinition = "varchar(32) comment '组'")
    private String cate;

    /**
     * 目标
     */
    @Column(columnDefinition = "bigint(64) comment '目标'")
    private Long targetId;

    /**
     * 创建时间
     */
    @CreatedDate
    @Column(columnDefinition = "datetime comment '创建时间'")
    private Date createTime;
}
