package com.chilunyc.fumao.place.request.coupon;

import com.chilunyc.fumao.place.model.enums.CouponKind;
import com.chilunyc.fumao.place.model.enums.CouponSendWay;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.hibernate.validator.constraints.NotBlank;

import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import java.util.Date;
import java.util.List;

/**
 *
 */
@ApiModel
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
public class CouponEditRequest {

    private Long id;

    @ApiModelProperty(value = "封面")
    private String cover;

    @NotBlank(message = "请输入名称")
    @ApiModelProperty(value = "名称")
    private String title;

    @ApiModelProperty(value = "副标题")
    private String subTitle;

    @NotNull(message = "请输入库存")
    @ApiModelProperty(value = "库存")
    private Long stock;

    @NotNull(message = "请选择限额")
    @ApiModelProperty(value = "限领")
    private Integer maxNum;

    @Size(min = 2, max = 2, message = "请选择发放日期")
    @ApiModelProperty(value = "发放日期")
    private Date[] open;

    @NotBlank(message = "请选择有效期类型")
    private String validType;

    @ApiModelProperty(value = "有效日期")
    private Date[] valid;

    @ApiModelProperty(value = "有效日")
    private Integer validDay;

    @NotBlank(message = "请输入使用须知")
    @ApiModelProperty(value = "使用须知")
    private String description;

    @ApiModelProperty(value = "商户")
    private Long merchantId;

    @NotNull(message = "请输入面额")
    @ApiModelProperty(value = "面值")
    private Double amount;

    @NotNull(message = "请输入使用条件")
    @ApiModelProperty(value = "售价")
    private Double requireAmount;

    @NotNull(message = "请选择卷类型")
    private CouponKind kind;

    @NotNull(message = "请选择发劵方式")
    private CouponSendWay sendWay;

    private Long placeId;

    @ApiModelProperty("是否草稿")
    private boolean draft;

    @ApiModelProperty("分类")
    @Size(min = 1, message = "请选择业态")
    private List<String> cateList;
}
