package com.chilunyc.fumao.place.service;

import com.chilunyc.fumao.common.request.IdsRequest;
import com.chilunyc.fumao.common.util.jpa.query.QueryBuilder;
import com.chilunyc.fumao.place.model.Coupon;
import com.chilunyc.fumao.place.model.CouponChannel;
import com.chilunyc.fumao.place.model.enums.CouponPutWay;
import com.chilunyc.fumao.place.repository.CouponChannelRepository;
import com.chilunyc.fumao.place.request.couponChannel.CouponChannelEditRequest;
import com.chilunyc.fumao.place.request.couponChannel.CouponChannelPageRequest;
import lombok.extern.log4j.Log4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;
import java.util.stream.Collectors;

/**
 *
 */
@Log4j
@Service
@Transactional
public class CouponChannelService {


    @Autowired
    private CouponChannelRepository couponChannelRepository;

    public Page<CouponChannel> page(CouponChannelPageRequest request) {
        return couponChannelRepository.findAll(QueryBuilder.build(request), request.getPage());
    }


    public CouponChannel find(Long id) {
        CouponChannel one = couponChannelRepository.findOne(id);
        return one;
    }


    public void edit(CouponChannelEditRequest request) {
        request
                .getCouponIdList()
                .forEach(couponId -> {
                    switch (request.getChannel()) {
                        case FlashSale:
                            // 判断是否加过限时抢购
                            if (!couponChannelRepository.existsByCouponIdAndChannel(couponId, CouponPutWay.FlashSale)) {
                                couponChannelRepository.save(
                                        CouponChannel
                                                .builder()
                                                .placeId(request.getPlaceId())
                                                .channel(request.getChannel())
                                                .couponId(couponId)
                                                .build());
                            }
                            break;
                        case List:
                            // 直接更新有分类的渠道
                            couponChannelRepository.updateCate(couponId, CouponPutWay.List);
                            break;
                    }
                });
    }

    public void remove(IdsRequest<Long> request) {
        request
                .getIds()
                .forEach((id) -> {
                    couponChannelRepository.delete(id);
                });
    }


    public void updateCoupon(Coupon coupon, List<String> cateList) {
        //1. 获取一条看看是否已经分配到列表渠道
        boolean hasList = couponChannelRepository.existsByCouponIdAndChannel(coupon.getId(), CouponPutWay.List);

        //2. 删掉分类, 重新加
        couponChannelRepository.deleteByCouponIdAndCateIsNotNull(coupon.getId());

        //3. 批量加
        if (cateList == null) {
            return;
        }

        couponChannelRepository.save(
                cateList
                        .stream()
                        .map(s ->
                                CouponChannel
                                        .builder()
                                        .couponId(coupon.getId())
                                        .placeId(coupon.getPlaceId())
                                        .channel(hasList ? CouponPutWay.List : null)
                                        .cate(s)
                                        .build()
                        )
                        .collect(Collectors.toList())
        );
    }

    public List<CouponChannel> findByCouponId(Long id, boolean hasCate) {
        if (hasCate) {
            return couponChannelRepository.findByCouponIdAndCateIsNotNull(id);
        } else {
            return couponChannelRepository.findByCouponId(id);
        }
    }
}
