package com.chilunyc.fumao.place.service;

import com.chilunyc.fumao.common.context.RequestHolder;
import com.chilunyc.fumao.common.log.model.EventTarget;
import com.chilunyc.fumao.common.log.model.EventType;
import com.chilunyc.fumao.common.log.service.EventService;
import com.chilunyc.fumao.common.request.IdsRequest;
import com.chilunyc.fumao.common.util.BeanHelper;
import com.chilunyc.fumao.common.util.jpa.query.QueryBuilder;
import com.chilunyc.fumao.place.model.Customer;
import com.chilunyc.fumao.place.repository.CustomerRepository;
import com.chilunyc.fumao.place.request.customer.CustomerEditRequest;
import com.chilunyc.fumao.place.request.customer.CustomerPageRequest;
import lombok.extern.log4j.Log4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 *
 */
@Log4j
@Service
@Transactional
public class CustomerService {


    @Autowired
    private CustomerRepository customerRepository;

    @Autowired
    private EventService eventService;

    @Autowired
    private TagService tagService;

    public Page<Customer> page(CustomerPageRequest request) {
        return customerRepository.findAll(QueryBuilder.build(request), request.getPage());
    }


    public Customer find(Long id) {
        Customer one = customerRepository.findOne(id);
        return one;
    }


    public Customer edit(CustomerEditRequest request) {
        Customer customer = new Customer();
        if (request.getId() != null) {
            customer = customerRepository.findOne(request.getId());
        }
        BeanHelper.copyProperties(customer, request);
        customer = customerRepository.save(customer);
        eventService.add(RequestHolder.get(), EventTarget.Place, EventType.编辑顾客, customer.getId(), request);
        if (request.getTagList() != null){
            tagService.assign(customer.getId(), request.getTagList());
        }
        return customer;
    }

    public void remove(IdsRequest<Long> request) {
        request
                .getIds()
                .forEach((id) -> {
                    customerRepository.delete(id);
                });
        eventService.add(RequestHolder.get(), EventTarget.Place, EventType.删除顾客, null, request.getIds());
    }


    public Customer findByMobile(String mobile) {
        return customerRepository.findByMobile(mobile);
    }
}
