package com.chilunyc.fumao.place.service;

import com.alibaba.fastjson.JSON;
import com.chilunyc.fumao.common.exception.SystemException;
import com.chilunyc.fumao.common.util.BeanHelper;
import com.chilunyc.fumao.place.model.PlaceSetting;
import com.chilunyc.fumao.place.model.enums.PlaceSettingType;
import com.chilunyc.fumao.place.repository.PlaceSettingRepository;
import com.chilunyc.fumao.place.request.placeSetting.PlaceSettingEditRequest;
import lombok.extern.log4j.Log4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 *
 */
@Log4j
@Service
@Transactional
public class PlaceSettingService {


    @Autowired
    private PlaceSettingRepository placeSettingRepository;


    public PlaceSetting get(Long placeId, PlaceSettingType type) {
        PlaceSetting placeSetting = placeSettingRepository.findByPlaceIdAndType(placeId, type);
        if (placeSetting != null) {
            return placeSetting;
        }
        return null;
    }


    public void set(PlaceSettingEditRequest request) {
        PlaceSetting placeSetting = get(request.getPlaceId(), request.getType());
        if (placeSetting == null) {
            placeSetting = new PlaceSetting();
        }
        BeanHelper.copyProperties(placeSetting, request);
        placeSettingRepository.save(placeSetting);
    }

    public <T> T get(Long placeId, PlaceSettingType type, Class<T> tClass) {
        PlaceSetting placeSetting = get(placeId, type);
        if (placeSetting != null) {
            return JSON.parseObject(placeSetting.getValue(), tClass);
        }
        throw new SystemException("100002", type.getMsg());
    }
}
